@@ -353,8 +353,9 @@ def render_timeline(commits, messages):
             role_cls = "user" if role == "user" else "assistant"
             body = escape_html(m.get("text", ""))
             ts = escape_html(m.get("ts", ""))
+            agent = escape_html(m.get("agent", "agent"))
             right.append(
-                f"<div class=\"message {role_cls}\"><div class=\"message-header\">{role} · {ts}</div>"
+                f"<div class=\"message {role_cls}\"><div class=\"message-header\">{role} · {agent} · {ts}</div>"
                 f"<div class=\"message-body\">{body}</div></div>"
             )
         left_html = "".join(left) if left else ""
@@ -449,8 +450,18 @@ def get_git_commits(last_commit):
     return commits
 
 
+def _detect_agent_name(command):
+    if not command:
+        return "agent"
+    base = os.path.basename(command[0])
+    if base in ("python", "python3") and len(command) > 1:
+        return os.path.basename(command[1])
+    return base
+
+
 def run_session(command):
     session_start = now_iso()
+    agent = _detect_agent_name(command)
     messages = []
     editor = SimpleLineRecorder()
     builder = OutputBuilder()
@@ -508,7 +519,7 @@ def run_session(command):
     except ChildProcessError:
         pass
 
-    return session_start, now_iso(), messages
+    return session_start, now_iso(), agent, messages
 
 
 def main():
@@ -517,7 +528,7 @@ def main():
         sys.exit(1)
 
     command = sys.argv[1:]
-    session_start, session_end, messages = run_session(command)
+    session_start, session_end, agent, messages = run_session(command)
 
     html_path = Path(os.getcwd()) / "codey.html"
     state = load_state(html_path)
@@ -540,12 +551,16 @@ def main():
         state.setdefault("conversations", []).append({
             "session_start": session_start,
             "session_end": session_end,
+            "agent": agent,
             "messages": messages,
         })
 
     flat_messages = []
     for session in state.get("conversations", []):
+        agent = session.get("agent", "agent")
         for m in session.get("messages", []):
+            if m.get("role") == "user":
+                m["agent"] = agent
             flat_messages.append(m)
     render_state = dict(state)
     render_state["conversations"] = flat_messages
